Class: Numerix::MatrixBase Abstract

Inherits:
Structure show all
Includes:
Enumerable
Defined in:
lib/numerix/matrix_base.rb

Overview

This class is abstract.

Abstract base class for matrix classes.

This class cannot be instantiated, it of only for providing a common base class for matrix types.

Direct Known Subclasses

Matrix3x2, Matrix4x4

Method Summary

Methods inherited from Structure

#[], #[]=, #address, #dup, #each, #pack, #ptr, size, unpack