Class: Numerix::Vector3

Inherits:
VectorBase show all
Defined in:
lib/numerix/vector3.rb

Overview

A structure encapsulating three single precision floating point values.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Structure

#[], #[]=, #address, #dup, #each, #pack, #ptr, size, unpack

Constructor Details

#initializeVector3 #initialize(xyz) ⇒ Vector3 #initialize(x, y, z) ⇒ Vector3 #initialize(xy, z) ⇒ Vector3

Returns a new instance of Vector3.

Overloads:

  • #initializeVector3

    Creates a Vector with the default values of 0.0.

  • #initialize(xyz) ⇒ Vector3

    Creates a Vector with each component set to a single value.

  • #initialize(x, y, z) ⇒ Vector3

    Creates a Vector with the specified values.

  • #initialize(xy, z) ⇒ Vector3

    Creates a Vector with the specified values.



41
42
# File 'lib/numerix/vector3.rb', line 41

def initialize(*args)
end

Instance Attribute Details

#xFloat



9
10
11
# File 'lib/numerix/vector3.rb', line 9

def x
  @x
end

#yFloat



13
14
15
# File 'lib/numerix/vector3.rb', line 13

def y
  @y
end

#zFloat



17
18
19
# File 'lib/numerix/vector3.rb', line 17

def z
  @z
end

Class Method Details

.clamp(min, max) ⇒ Vector3 .clamp(min, max) ⇒ Vector3

Returns a vector that is result of clamping a vector between the specified minimum and maximum values.

Overloads:

  • .clamp(min, max) ⇒ Vector3

    Clamps the vector's components between the specified values.

  • .clamp(min, max) ⇒ Vector3

    Clamps the vector's on a component-wise basis between the minimum and maximum values of the specified vectors.



514
515
# File 'lib/numerix/vector3.rb', line 514

def clamp(vector, min, max)
end

.create_norm(x, y, z) ⇒ Vector3

Creates and returns a normalized vector from the specified components.

This is more efficient than creating and then normalizing.



493
494
# File 'lib/numerix/vector3.rb', line 493

def create_norm(x, y, z)
end

.lerp(vector1, vector2, amount) ⇒ Vector3

Linearly interpolates between two vectors based on the given weighting.



526
527
# File 'lib/numerix/vector3.rb', line 526

def lerp(vector1, vector2, amount)
end

.max(vector, other) ⇒ Vector3 .max(vector, value) ⇒ Vector3

Returns a vector with a maximum set of values.

Overloads:

  • .max(vector, other) ⇒ Vector3

    Returns a vector whose elements are the maximum of each of the pairs of elements in the two source vectors.

  • .max(vector, value) ⇒ Vector3

    Returns a vector whose elements are the maximum of each of vector element and the specified value.



568
569
# File 'lib/numerix/vector3.rb', line 568

def max(vector, other)
end

.min(vector, other) ⇒ Vector3 .min(vector, value) ⇒ Vector3

Returns a vector with a minimum set of values.

Overloads:

  • .min(vector, other) ⇒ Vector3

    Returns a vector whose elements are the minimum of each of the pairs of elements in the two source vectors.

  • .min(vector, value) ⇒ Vector3

    Returns a vector whose elements are the minimum of each of vector element and the specified value.



547
548
# File 'lib/numerix/vector3.rb', line 547

def min(vector, other)
end

.oneVector3



465
466
# File 'lib/numerix/vector3.rb', line 465

def one
end

.unit_xVector3



470
471
# File 'lib/numerix/vector3.rb', line 470

def unit_x
end

.unit_yVector3



475
476
# File 'lib/numerix/vector3.rb', line 475

def unit_y
end

.unit_zVector3



480
481
# File 'lib/numerix/vector3.rb', line 480

def unit_z
end

.zeroVector3



460
461
# File 'lib/numerix/vector3.rb', line 460

def zero
end

Instance Method Details

#*(scalar) ⇒ Vector3 #*(other) ⇒ Vector3

Vector multiplication.

Overloads:

  • #*(scalar) ⇒ Vector3

    Scalar vector multiplication.

  • #*(other) ⇒ Vector3

    Multiplies this vector by another.



318
319
# File 'lib/numerix/vector3.rb', line 318

def *(other)
end

#**(exponent) ⇒ Vector3

Raises the vector to the given power.



97
98
# File 'lib/numerix/vector3.rb', line 97

def **(exponent)
end

#+(other) ⇒ Vector3

Adds this vector with another.



292
293
# File 'lib/numerix/vector3.rb', line 292

def +(other)
end

#-(other) ⇒ Vector3

Gets the difference of this vector and another.



301
302
# File 'lib/numerix/vector3.rb', line 301

def -(other)
end

#-@Vector3

Performs unary negation on this vector instance.



351
352
# File 'lib/numerix/vector3.rb', line 351

def -@
end

#*(scalar) ⇒ Vector3 #*(other) ⇒ Vector3

Vector division.

Overloads:

  • #*(scalar) ⇒ Vector3

    Scalar vector division.

  • #*(other) ⇒ Vector3

    Divides this vector by another.



335
336
# File 'lib/numerix/vector3.rb', line 335

def /(other)
end

#==(other) ⇒ Boolean

Returns flag if this vector instance is equal to the given object.



344
345
# File 'lib/numerix/vector3.rb', line 344

def ==(other)
end

#absVector3



186
187
# File 'lib/numerix/vector3.rb', line 186

def abs
end

#angle(other) ⇒ Float

Computes the angle between this vector and another.



453
454
# File 'lib/numerix/vector3.rb', line 453

def angle(other)
end

#clamp(min, max) ⇒ Vector3 #clamp(min, max) ⇒ Vector3

Returns a vector that is result of clamping this vector between the specified minimum and maximum values.

Overloads:

  • #clamp(min, max) ⇒ Vector3

    Clamps the vector's components between the specified values.

  • #clamp(min, max) ⇒ Vector3

    Clamps the vector's on a component-wise basis between the minimum and maximum values of the specified vectors.

See Also:



224
225
# File 'lib/numerix/vector3.rb', line 224

def clamp(min, max)
end

#clamp!(min, max) ⇒ Vector3 #clamp!(min, max) ⇒ Vector3

Clamps this vector between the specified minimum and maximum values.

Overloads:

  • #clamp!(min, max) ⇒ Vector3

    Clamps the vector's components between the specified values.

  • #clamp!(min, max) ⇒ Vector3

    Clamps the vector's on a component-wise basis between the minimum and maximum values of the specified vectors.

See Also:



246
247
# File 'lib/numerix/vector3.rb', line 246

def clamp!(min, max)
end

#cross(other) ⇒ Vector3

Computes the cross product of two vectors.



416
417
# File 'lib/numerix/vector3.rb', line 416

def cross(other)
end

#cross!(other) ⇒ self

Computes the cross product of two vectors, altering the values of this vector.



425
426
# File 'lib/numerix/vector3.rb', line 425

def cross!(other)
end

#distance(vector) ⇒ Float

Returns the Euclidean distance between this vector and another.



128
129
# File 'lib/numerix/vector3.rb', line 128

def distance(vector)
end

#distance_squared(vector) ⇒ Float

Returns the squared Euclidean distance between this vector and another.



136
137
# File 'lib/numerix/vector3.rb', line 136

def distance_squared(vector)
end

#dot(other) ⇒ Float

Returns the dot product of this vector and another.



201
202
# File 'lib/numerix/vector3.rb', line 201

def dot(other)
end

#lengthFloat Also known as: magnitude



46
47
# File 'lib/numerix/vector3.rb', line 46

def length
end

#length_squaredFloat



53
54
# File 'lib/numerix/vector3.rb', line 53

def length_squared
end

#lerp(vector, amount) ⇒ Vector3

Linearly interpolates between this vector and another based on the given weighting.

See Also:



166
167
# File 'lib/numerix/vector3.rb', line 166

def lerp(vector, amount)
end

#lerp!(vector, amount) ⇒ self

Linearly interpolates between this vector and another based on the given weighting, altering the values of this vector.

See Also:



180
181
# File 'lib/numerix/vector3.rb', line 180

def lerp!(vector, amount)
end

#mapObject Also known as: collect

See Also:



70
71
# File 'lib/numerix/vector3.rb', line 70

def map
end

#map! {|component| ... } ⇒ self Also known as: collect!

Invokes the given block once for each element of self, replacing the element with the value returned by the block.

The values of the vector are altered without creating a ne object.

Yields:

  • (component)

    Yields a component of the vector to the block.

Yield Parameters:

  • component (Float)

    The yielded component.

See Also:



85
86
# File 'lib/numerix/vector3.rb', line 85

def map!
end

#max_valueFloat



119
120
# File 'lib/numerix/vector3.rb', line 119

def max_value
end

#min_valueFloat



114
115
# File 'lib/numerix/vector3.rb', line 114

def min_value
end

#normalizeVector3

Returns a new vector with the same direction as the given vector, but with a length of 1.0.



144
145
# File 'lib/numerix/vector3.rb', line 144

def normalize
end

#normalize!self

Alters this vector instance to maintain same direction, but adjust values so that vector has a length of 1.0.



152
153
# File 'lib/numerix/vector3.rb', line 152

def normalize!
end

#one?Boolean



103
104
# File 'lib/numerix/vector3.rb', line 103

def one?
end

#reflect(other) ⇒ Vector3

Alters this vector to be the reflection of the specified normal.



434
435
# File 'lib/numerix/vector3.rb', line 434

def reflect(other)
end

#reflect!(other) ⇒ self

Returns the reflection of a vector off a surface that has the specified normal.



444
445
# File 'lib/numerix/vector3.rb', line 444

def reflect!(other)
end

#sqrtVector3



192
193
# File 'lib/numerix/vector3.rb', line 192

def sqrt
end

#to_aArray<Float> Also known as: elements



256
257
# File 'lib/numerix/vector3.rb', line 256

def to_a
end

#to_hHash{Symbol => Float}



263
264
# File 'lib/numerix/vector3.rb', line 263

def to_h
end

#to_planePlane



273
274
# File 'lib/numerix/vector3.rb', line 273

def to_plane
end

#to_quaternionQuaternion



268
269
# File 'lib/numerix/vector3.rb', line 268

def to_quaternion
end

#to_sString



251
252
# File 'lib/numerix/vector3.rb', line 251

def to_s
end

#to_vec2Vector2



278
279
# File 'lib/numerix/vector3.rb', line 278

def to_vec2
end

#to_vec4Vector4



283
284
# File 'lib/numerix/vector3.rb', line 283

def to_vec4
end

#transform(matrix) ⇒ Vector3 #transform(rotation) ⇒ Vector3

Returns a new vector by applying a transformation.

Overloads:

  • #transform(matrix) ⇒ Vector3

    Transforms this vector by the given matrix.

  • #transform(rotation) ⇒ Vector3

    Transforms this vector by the specified rotation value.

See Also:



370
371
# File 'lib/numerix/vector3.rb', line 370

def transform(other)
end

#transform(matrix) ⇒ self #transform(rotation) ⇒ self

Transforms this vector by the given matrix.

Overloads:

  • #transform(matrix) ⇒ self

    Transforms this vector by the given matrix.

  • #transform(rotation) ⇒ self

    Transforms this vector by the specified rotation value.

See Also:



389
390
# File 'lib/numerix/vector3.rb', line 389

def transform!(other)
end

#transform_normal(matrix) ⇒ Vector3

Transforms a vector normal by the given matrix.



398
399
# File 'lib/numerix/vector3.rb', line 398

def transform_normal(matrix)
end

#transform_normal!(matrix) ⇒ self

Transforms a vector normal by the given matrix.



407
408
# File 'lib/numerix/vector3.rb', line 407

def transform_normal!(matrix)
end

#zero?Boolean



109
110
# File 'lib/numerix/vector3.rb', line 109

def zero?
end