Class: Numerix::VectorBase Abstract

Inherits:
Structure show all
Includes:
Enumerable
Defined in:
lib/numerix/vector_base.rb

Overview

This class is abstract.

Abstract base class for Vector objects.

This class cannot be instantiated, it of only for providing a common base class for vector types.

Direct Known Subclasses

Vector2, Vector3, Vector4

Method Summary

Methods inherited from Structure

#[], #[]=, #address, #dup, #each, #pack, #ptr, size, unpack